package loggo

import (
	"fmt"
	"path"
	"strings"
	"time"
)

// Formatter defines the single method Format, which takes the logging
// information, and converts it to a string.
type Formatter interface {
	Format(level Level, module, filename string, line int, timestamp time.Time, message string) string
}

// DefaultFormatter provides a simple concatination of all the components.
type DefaultFormatter struct{}

// Format returns the parameters separated by spaces except for filename and
// line which are separated by a colon.  The timestamp is only shown to second
// resolution, and no timezone is shown.
func (*DefaultFormatter) Format(level Level, module, filename string, line int, timestamp time.Time, message string) string {
	// Chop off the .ns +tz part of the timestamp string
	ts := strings.SplitN(fmt.Sprint(timestamp), ".", 2)
	// Just get the basename from the filename
	filename = path.Base(filename)
	return fmt.Sprintf("%s %s %s %s:%d %s", ts[0], level, module, filename, line, message)
}
